@@ -1,6 +1,6 @@
 //===========================================
 //  Lumina-DE source code
-//  Copyright (c) 2014, Ken Moore
+//  Copyright (c) 2014-2015, Ken Moore
 //  Available under the 3-clause BSD license
 //  See the LICENSE file for full details
 //===========================================
@@ -17,6 +17,9 @@
 #include <QFile>
 #include <QDir>
 #include <QTimer>
+#include <QDateTime>
+#include <QStyle>
+#include <QProxyStyle>
 
 class LTHEME{
 public:
@@ -26,25 +29,54 @@ public:
   static QStringList availableSystemColors(); 	//returns: [name::::path] for each item
   static QStringList availableLocalColors(); 	//returns: [name::::path] for each item
   static QStringList availableSystemIcons(); 	//returns: [name] for each item
-	
+  static QStringList availableSystemCursors();	//returns: [name] for each item
+
   //Save a new theme/color file
   static bool saveLocalTheme(QString name, QStringList contents);
   static bool saveLocalColors(QString name, QStringList contents);
-
+  
   //Return the currently selected Theme/Colors/Icons
   static QStringList currentSettings(); //returns [theme path, colorspath, iconsname, font, fontsize]
+  static QString currentCursor(); //returns: current cursor theme name
 
   //Change the current Theme/Colors/Icons
   static bool setCurrentSettings(QString themepath, QString colorpath, QString iconname, QString font, QString fontsize);
-	
+  static bool setCursorTheme(QString cursorname);
+
   //Return the complete stylesheet for a given theme/colors
   static QString assembleStyleSheet(QString themepath, QString colorpath, QString font, QString fontsize);
   
+  //Additional info for a cursor theme
+  static QStringList cursorInformation(QString name); //returns: [Name, Comment, Sample Image File]
+  
+  //Environment settings
+  static QStringList CustomEnvSettings(); //view all the key=value settings
+  static void LoadCustomEnvSettings(); //will push the custom settings into the environment (recommended before loading the initial QApplication)
+  static bool setCustomEnvSetting(QString var, QString val); //variable/value pair (use an empty val to clear it)
+  static QString readCustomEnvSetting(QString var);
+  
 };
 
+// Qt Style override to allow custom themeing/colors
+/*class LuminaThemeStyle : public QProxyStyle{
+	Q_OBJECT
+private:
+	bool darkfont;
+
+public:
+	LuminaThemeStyle();
+	~LuminaThemeStyle();
+
+	//Function to update the style (for use by the theme engine)
+	void update();	
+	//Subclassed functions 
+	void drawItemText(QPainter*, const QRect&, int, const QPalette&, bool, const QString&, QPalette::ColorRole) const;
+
+};*/
 
 //Simple class to setup a utility to use the Lumina theme
 //-----Example usage in "main.cpp" -------------------------------
+// LTHEME::LoadCustomEnvSettings();
 // QApplication a(argc,argv);
 // LuminaThemeEngine themes(&a)
 //------------------------------------------------------------------------------------
@@ -63,16 +95,19 @@ public:
 private:
 	QApplication *application;
 	QFileSystemWatcher *watcher;
-	QString theme,colors,icons, font, fontsize; //current settings
+	QString theme,colors,icons, font, fontsize, cursors; //current settings
 	QTimer *syncTimer;
+	QDateTime lastcheck;
+	//LuminaThemeStyle *style;
 
 private slots:
 	void watcherChange();
 	void reloadFiles();
 
 signals:
-	void updateIcons();
-};
-
+	void updateIcons(); 		//Icon theme changed
+	void updateCursors(); 	//Cursor theme changed
+	void EnvChanged(); 		//Some environment variable(s) changed
+};	
 
 #endif
