@@ -30,11 +30,27 @@
 #include <QDateTime>
 #include <QDebug>
 
+
+// ======================
+// FreeDesktop Desktop Actions Framework (data structure)
+// ======================
+class XDGDesktopAction{
+public:
+  //Admin variables
+  QString ID; //The ID name for this action (should correspond to an entry in the "actionList" for the XDGDesktop below)
+  //General Variables
+  QString name, icon, exec;
+};
+
+// ======================
+//  FreeDesktop Desktop Entry Framework (data structure)
+// ======================
 class XDGDesktop{
 public:
   enum XDGDesktopType { BAD, APP, LINK, DIR };
   //Admin variables
   QString filePath; //which file this structure contains the information for (absolute path)
+  QDateTime lastRead; //when this structure was created from the file
   XDGDesktopType type;
   //General variables
   QString name, genericName, comment, icon;
@@ -44,6 +60,7 @@ public:
   QString exec, tryexec, path, startupWM;
   QStringList actionList, mimeList, catList, keyList;
   bool useTerminal, startupNotify;
+  QList<XDGDesktopAction> actions;
   //Type 2 (LINK) variables
   QString url;
   
@@ -52,11 +69,50 @@ public:
   ~XDGDesktop(){}
 };
 
+// ========================
+// File Information simplification class (combine QFileInfo with XDGDesktop)
+//  Need some extra information not usually available by a QFileInfo
+// ========================
+class LFileInfo : public QFileInfo{
+private:
+	QString mime, icon;
+	XDGDesktop desk;
 
+	void loadExtraInfo();
+	
+public:
+	//Couple overloaded contructors
+	LFileInfo(QString filepath);
+	LFileInfo(QFileInfo info);
+	~LFileInfo(){}
+	
+	//Functions for accessing the extra information
+	// -- Return the mimetype for the file
+	QString mimetype();
+	
+	// -- Return the icon file to use for this file
+	QString iconfile(); //Note: This string is auto-formatted for use in the LXDG::findIcon() routine.
+	
+	// -- Check if this is an XDG desktop file
+	bool isDesktopFile();
+	
+	// -- Allow access to the internal XDG desktop data structure
+	XDGDesktop* XDG();
+	
+	//Other file type identification routines
+	bool isImage(); //Is a readable image file (for thumbnail support)
+	bool isAVFile(); //Is an audio/video file
+};
+typedef QList<LFileInfo> LFileInfoList;
+
+// ================================
+//  Collection of FreeDesktop standards interaction routines
+// ================================
 class LXDG{
 public:
-	//Read a *.desktop file
+	//Read/write a *.desktop file
 	static XDGDesktop loadDesktopFile(QString filePath, bool& ok);
+	static bool saveDesktopFile(XDGDesktop dFile, bool merge = true);
 	//Check a *.desktop file for validity (showAll skips the DE-exclusivity checks)
 	static bool checkValidity(XDGDesktop dFile, bool showAll = true); 
 	//Check for a valid executable
@@ -70,7 +126,7 @@ public:
 	//Sort a list of Desktop files by name
 	static QList<XDGDesktop> sortDesktopNames(QList<XDGDesktop> apps);
 	//Get the executable line from a Desktop file
-	static QString getDesktopExec(XDGDesktop);
+	static QString getDesktopExec(XDGDesktop app, QString ActionID = "");
 	//Set all the default XDG Environment variables
 	static void setEnvironmentVars();
 	//Find an icon from the current/default theme
@@ -102,6 +158,8 @@ public:
 	
 	//Find all the autostart *.desktop files
 	static QList<XDGDesktop> findAutoStartFiles(bool includeInvalid = false);
+	static bool setAutoStarted(bool autostart, XDGDesktop app);
+	static bool setAutoStarted(bool autostart, QString filePath); //for convenience
 };
 
 #endif
